@@ -43,6 +43,6 @@ def get_dag_source(*, file_token: str) -> Response:
     if return_type == "text/plain":
         return Response(dag_source, headers={"Content-Type": return_type})
     if return_type == "application/json":
-        content = dag_source_schema.dumps(dict(content=dag_source))
+        content = dag_source_schema.dumps({"content": dag_source})
         return Response(content, headers={"Content-Type": return_type})
     return Response("Not Allowed Accept Header", status=HTTPStatus.NOT_ACCEPTABLE)
