@@ -23,13 +23,15 @@ from typing import Any, Sequence
 import botocore.exceptions
 from botocore.exceptions import ClientError
 
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseAsyncHook, AwsBaseHook
 
 
 class RedshiftHook(AwsBaseHook):
-    """
-    Interact with Amazon Redshift.
-    Provide thin wrapper around :external+boto3:py:class:`boto3.client("redshift") <Redshift.Client>`.
+    """Interact with Amazon Redshift.
+
+    This is a thin wrapper around
+    :external+boto3:py:class:`boto3.client("redshift") <Redshift.Client>`.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
@@ -52,8 +54,7 @@ class RedshiftHook(AwsBaseHook):
         master_user_password: str,
         params: dict[str, Any],
     ) -> dict[str, Any]:
-        """
-        Creates a new cluster with the specified parameters
+        """Create a new cluster with the specified parameters.
 
         .. seealso::
             - :external+boto3:py:meth:`Redshift.Client.create_cluster`
@@ -83,8 +84,7 @@ class RedshiftHook(AwsBaseHook):
 
     # TODO: Wrap create_cluster_snapshot
     def cluster_status(self, cluster_identifier: str) -> str:
-        """
-        Return status of a cluster
+        """Get status of a cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`Redshift.Client.describe_clusters`
@@ -105,8 +105,7 @@ class RedshiftHook(AwsBaseHook):
         skip_final_cluster_snapshot: bool = True,
         final_cluster_snapshot_identifier: str | None = None,
     ):
-        """
-        Delete a cluster and optionally create a snapshot
+        """Delete a cluster and optionally create a snapshot.
 
         .. seealso::
             - :external+boto3:py:meth:`Redshift.Client.delete_cluster`
@@ -125,8 +124,7 @@ class RedshiftHook(AwsBaseHook):
         return response["Cluster"] if response["Cluster"] else None
 
     def describe_cluster_snapshots(self, cluster_identifier: str) -> list[str] | None:
-        """
-        Gets a list of snapshots for a cluster
+        """List snapshots for a cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`Redshift.Client.describe_cluster_snapshots`
@@ -142,8 +140,7 @@ class RedshiftHook(AwsBaseHook):
         return snapshots
 
     def restore_from_cluster_snapshot(self, cluster_identifier: str, snapshot_identifier: str) -> str:
-        """
-        Restores a cluster from its snapshot
+        """Restore a cluster from its snapshot.
 
         .. seealso::
             - :external+boto3:py:meth:`Redshift.Client.restore_from_cluster_snapshot`
@@ -157,10 +154,13 @@ class RedshiftHook(AwsBaseHook):
         return response["Cluster"] if response["Cluster"] else None
 
     def create_cluster_snapshot(
-        self, snapshot_identifier: str, cluster_identifier: str, retention_period: int = -1
+        self,
+        snapshot_identifier: str,
+        cluster_identifier: str,
+        retention_period: int = -1,
+        tags: list[Any] | None = None,
     ) -> str:
-        """
-        Creates a snapshot of a cluster
+        """Create a snapshot of a cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`Redshift.Client.create_cluster_snapshot`
@@ -169,30 +169,25 @@ class RedshiftHook(AwsBaseHook):
         :param cluster_identifier: unique identifier of a cluster
         :param retention_period: The number of days that a manual snapshot is retained.
             If the value is -1, the manual snapshot is retained indefinitely.
+        :param tags: A list of tag instances
         """
+        if tags is None:
+            tags = []
         response = self.get_conn().create_cluster_snapshot(
             SnapshotIdentifier=snapshot_identifier,
             ClusterIdentifier=cluster_identifier,
             ManualSnapshotRetentionPeriod=retention_period,
+            Tags=tags,
         )
         return response["Snapshot"] if response["Snapshot"] else None
 
-    def get_cluster_snapshot_status(self, snapshot_identifier: str, cluster_identifier: str | None = None):
-        """
-        Return Redshift cluster snapshot status. If cluster snapshot not found return ``None``
+    def get_cluster_snapshot_status(self, snapshot_identifier: str):
+        """Get Redshift cluster snapshot status.
+
+        If cluster snapshot not found, *None* is returned.
 
         :param snapshot_identifier: A unique identifier for the snapshot that you are requesting
-        :param cluster_identifier: (deprecated) The unique identifier of the cluster
-            the snapshot was created from
         """
-        if cluster_identifier:
-            warnings.warn(
-                "Parameter `cluster_identifier` is deprecated."
-                "This option will be removed in a future version.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         try:
             response = self.get_conn().describe_cluster_snapshots(
                 SnapshotIdentifier=snapshot_identifier,
@@ -205,16 +200,20 @@ class RedshiftHook(AwsBaseHook):
 
 
 class RedshiftAsyncHook(AwsBaseAsyncHook):
-    """Interact with AWS Redshift using aiobotocore library"""
+    """Interact with AWS Redshift using aiobotocore library."""
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "airflow.providers.amazon.aws.hook.base_aws.RedshiftAsyncHook has been deprecated and "
+            "will be removed in future",
+            AirflowProviderDeprecationWarning,
+            stacklevel=2,
+        )
         kwargs["client_type"] = "redshift"
         super().__init__(*args, **kwargs)
 
     async def cluster_status(self, cluster_identifier: str, delete_operation: bool = False) -> dict[str, Any]:
-        """
-        Connects to the AWS redshift cluster via aiobotocore and get the status
-        and returns the status of the cluster based on the cluster_identifier passed
+        """Get the cluster status.
 
         :param cluster_identifier: unique identifier of a cluster
         :param delete_operation: whether the method has been called as part of delete cluster operation
@@ -232,9 +231,7 @@ class RedshiftAsyncHook(AwsBaseAsyncHook):
                 return {"status": "error", "message": str(error)}
 
     async def pause_cluster(self, cluster_identifier: str, poll_interval: float = 5.0) -> dict[str, Any]:
-        """
-        Connects to the AWS redshift cluster via aiobotocore and
-        pause the cluster based on the cluster_identifier passed
+        """Pause the cluster.
 
         :param cluster_identifier: unique identifier of a cluster
         :param poll_interval: polling period in seconds to check for the status
@@ -261,9 +258,7 @@ class RedshiftAsyncHook(AwsBaseAsyncHook):
         cluster_identifier: str,
         polling_period_seconds: float = 5.0,
     ) -> dict[str, Any]:
-        """
-        Connects to the AWS redshift cluster via aiobotocore and
-        resume the cluster for the cluster_identifier passed
+        """Resume the cluster.
 
         :param cluster_identifier: unique identifier of a cluster
         :param polling_period_seconds: polling period in seconds to check for the status
@@ -292,8 +287,7 @@ class RedshiftAsyncHook(AwsBaseAsyncHook):
         flag: asyncio.Event,
         delete_operation: bool = False,
     ) -> dict[str, Any]:
-        """
-        check for expected Redshift cluster state
+        """Check for expected Redshift cluster state.
 
         :param cluster_identifier: unique identifier of a cluster
         :param expected_state: expected_state example("available", "pausing", "paused"")
