@@ -14,10 +14,11 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import argparse
 import json
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 from airflow.providers.amazon.aws.hooks.eks import EksHook
 
@@ -27,24 +28,25 @@ TOKEN_EXPIRATION_MINUTES = 14
 
 
 def get_expiration_time():
-    token_expiration = datetime.utcnow() + timedelta(minutes=TOKEN_EXPIRATION_MINUTES)
-    return token_expiration.strftime('%Y-%m-%dT%H:%M:%SZ')
+    token_expiration = datetime.now(timezone.utc) + timedelta(minutes=TOKEN_EXPIRATION_MINUTES)
+
+    return token_expiration.strftime("%Y-%m-%dT%H:%M:%SZ")
 
 
 def get_parser():
-    parser = argparse.ArgumentParser(description='Get a token for authentication with an Amazon EKS cluster.')
+    parser = argparse.ArgumentParser(description="Get a token for authentication with an Amazon EKS cluster.")
     parser.add_argument(
-        '--cluster-name', help='The name of the cluster to generate kubeconfig file for.', required=True
+        "--cluster-name", help="The name of the cluster to generate kubeconfig file for.", required=True
     )
     parser.add_argument(
-        '--aws-conn-id',
+        "--aws-conn-id",
         help=(
-            'The Airflow connection used for AWS credentials. '
-            'If not specified or empty then the default boto3 behaviour is used.'
+            "The Airflow connection used for AWS credentials. "
+            "If not specified or empty then the default boto3 behaviour is used."
         ),
     )
     parser.add_argument(
-        '--region-name', help='AWS region_name. If not specified then the default boto3 behaviour is used.'
+        "--region-name", help="AWS region_name. If not specified then the default boto3 behaviour is used."
     )
 
     return parser
@@ -65,5 +67,5 @@ def main():
     print(json.dumps(exec_credential_object))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
