@@ -28,9 +28,20 @@ class BaseBotoWaiter:
     For more details, see airflow/providers/amazon/aws/waiters/README.md
     """
 
-    def __init__(self, client: boto3.client, model_config: dict) -> None:
+    def __init__(self, client: boto3.client, model_config: dict, deferrable: bool = False) -> None:
         self.model = WaiterModel(model_config)
         self.client = client
+        self.deferrable = deferrable
+
+    def _get_async_waiter_with_client(self, waiter_name: str):
+        from aiobotocore.waiter import create_waiter_with_client as create_async_waiter_with_client
+
+        return create_async_waiter_with_client(
+            waiter_name=waiter_name, waiter_model=self.model, client=self.client
+        )
 
     def waiter(self, waiter_name: str) -> Waiter:
+        if self.deferrable:
+            return self._get_async_waiter_with_client(waiter_name=waiter_name)
+
         return create_waiter_with_client(waiter_name=waiter_name, waiter_model=self.model, client=self.client)
