@@ -15,10 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """This module contains operator to move data from Hive to Druid."""
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.apache.druid.hooks.druid import DruidHook
@@ -32,10 +32,10 @@ DEFAULT_TARGET_PARTITION_SIZE = 5000000
 
 
 class HiveToDruidOperator(BaseOperator):
-    """
-    Moves data from Hive to Druid, [del]note that for now the data is loaded
-    into memory before being pushed to Druid, so this operator should
-    be used for smallish amount of data.[/del]
+    """Moves data from Hive to Druid.
+
+    [del]note that for now the data is loaded into memory before being pushed to
+    Druid, so this operator should be used for smallish amount of data.[/del]
 
     :param sql: SQL query to execute against the Druid database. (templated)
     :param druid_datasource: the datasource you want to ingest into in druid
@@ -64,9 +64,9 @@ class HiveToDruidOperator(BaseOperator):
     :param job_properties: additional properties for job
     """
 
-    template_fields: Sequence[str] = ('sql', 'intervals')
-    template_ext: Sequence[str] = ('.sql',)
-    template_fields_renderers = {'sql': 'hql'}
+    template_fields: Sequence[str] = ("sql", "intervals")
+    template_ext: Sequence[str] = (".sql",)
+    template_fields_renderers = {"sql": "hql"}
 
     def __init__(
         self,
@@ -74,25 +74,25 @@ class HiveToDruidOperator(BaseOperator):
         sql: str,
         druid_datasource: str,
         ts_dim: str,
-        metric_spec: Optional[List[Any]] = None,
-        hive_cli_conn_id: str = 'hive_cli_default',
-        druid_ingest_conn_id: str = 'druid_ingest_default',
-        metastore_conn_id: str = 'metastore_default',
-        hadoop_dependency_coordinates: Optional[List[str]] = None,
-        intervals: Optional[List[Any]] = None,
+        metric_spec: list[Any] | None = None,
+        hive_cli_conn_id: str = "hive_cli_default",
+        druid_ingest_conn_id: str = "druid_ingest_default",
+        metastore_conn_id: str = "metastore_default",
+        hadoop_dependency_coordinates: list[str] | None = None,
+        intervals: list[Any] | None = None,
         num_shards: float = -1,
         target_partition_size: int = -1,
         query_granularity: str = "NONE",
         segment_granularity: str = "DAY",
-        hive_tblproperties: Optional[Dict[Any, Any]] = None,
-        job_properties: Optional[Dict[Any, Any]] = None,
+        hive_tblproperties: dict[Any, Any] | None = None,
+        job_properties: dict[Any, Any] | None = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
         self.sql = sql
         self.druid_datasource = druid_datasource
         self.ts_dim = ts_dim
-        self.intervals = intervals or ['{{ ds }}/{{ tomorrow_ds }}']
+        self.intervals = intervals or ["{{ ds }}/{{ tomorrow_ds }}"]
         self.num_shards = num_shards
         self.target_partition_size = target_partition_size
         self.query_granularity = query_granularity
@@ -105,12 +105,12 @@ class HiveToDruidOperator(BaseOperator):
         self.hive_tblproperties = hive_tblproperties or {}
         self.job_properties = job_properties
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hive = HiveCliHook(hive_cli_conn_id=self.hive_cli_conn_id)
         self.log.info("Extracting data from Hive")
-        hive_table = 'druid.' + context['task_instance_key_str'].replace('.', '_')
-        sql = self.sql.strip().strip(';')
-        tblproperties = ''.join(f", '{k}' = '{v}'" for k, v in self.hive_tblproperties.items())
+        hive_table = "druid." + context["task_instance_key_str"].replace(".", "_")
+        sql = self.sql.strip().strip(";")
+        tblproperties = "".join(f", '{k}' = '{v}'" for k, v in self.hive_tblproperties.items())
         hql = f"""\
         SET mapred.output.compress=false;
         SET hive.exec.compress.output=false;
@@ -152,7 +152,7 @@ class HiveToDruidOperator(BaseOperator):
             hql = f"DROP TABLE IF EXISTS {hive_table}"
             hive.run_cli(hql)
 
-    def construct_ingest_query(self, static_path: str, columns: List[str]) -> Dict[str, Any]:
+    def construct_ingest_query(self, static_path: str, columns: list[str]) -> dict[str, Any]:
         """
         Builds an ingest query for an HDFS TSV load.
 
@@ -170,13 +170,13 @@ class HiveToDruidOperator(BaseOperator):
         else:
             num_shards = -1
 
-        metric_names = [m['fieldName'] for m in self.metric_spec if m['type'] != 'count']
+        metric_names = [m["fieldName"] for m in self.metric_spec if m["type"] != "count"]
 
         # Take all the columns, which are not the time dimension
         # or a metric, as the dimension columns
         dimensions = [c for c in columns if c not in metric_names and c != self.ts_dim]
 
-        ingest_query_dict: Dict[str, Any] = {
+        ingest_query_dict: dict[str, Any] = {
             "type": "index_hadoop",
             "spec": {
                 "dataSchema": {
@@ -220,9 +220,9 @@ class HiveToDruidOperator(BaseOperator):
         }
 
         if self.job_properties:
-            ingest_query_dict['spec']['tuningConfig']['jobProperties'].update(self.job_properties)
+            ingest_query_dict["spec"]["tuningConfig"]["jobProperties"].update(self.job_properties)
 
         if self.hadoop_dependency_coordinates:
-            ingest_query_dict['hadoopDependencyCoordinates'] = self.hadoop_dependency_coordinates
+            ingest_query_dict["hadoopDependencyCoordinates"] = self.hadoop_dependency_coordinates
 
         return ingest_query_dict
