@@ -123,7 +123,7 @@ class HiveOperator(BaseOperator):
         self.hook: HiveCliHook | None = None
 
     def get_hook(self) -> HiveCliHook:
-        """Get Hive cli hook"""
+        """Get Hive cli hook."""
         return HiveCliHook(
             hive_cli_conn_id=self.hive_cli_conn_id,
             run_as=self.run_as,
