@@ -19,7 +19,6 @@
 from __future__ import annotations
 
 import enum
-import warnings
 from typing import Sequence
 
 from google.cloud.bigtable import Client, enums
@@ -43,16 +42,16 @@ class BigtableHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
             )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self._client: Client | None = None
@@ -70,8 +69,7 @@ class BigtableHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def get_instance(self, instance_id: str, project_id: str) -> Instance | None:
         """
-        Retrieves and returns the specified Cloud Bigtable instance if it exists.
-        Otherwise, returns None.
+        Retrieves and returns the specified Cloud Bigtable instance if it exists, otherwise returns None.
 
         :param instance_id: The ID of the Cloud Bigtable instance.
         :param project_id: Optional, Google Cloud  project ID where the
@@ -87,6 +85,7 @@ class BigtableHook(GoogleBaseHook):
     def delete_instance(self, instance_id: str, project_id: str) -> None:
         """
         Deletes the specified Cloud Bigtable instance.
+
         Raises google.api_core.exceptions.NotFound if the Cloud Bigtable instance does
         not exist.
 
@@ -218,6 +217,7 @@ class BigtableHook(GoogleBaseHook):
     ) -> None:
         """
         Creates the specified Cloud Bigtable table.
+
         Raises ``google.api_core.exceptions.AlreadyExists`` if the table exists.
 
         :param instance: The Cloud Bigtable instance that owns the table.
@@ -239,6 +239,7 @@ class BigtableHook(GoogleBaseHook):
     def delete_table(self, instance_id: str, table_id: str, project_id: str) -> None:
         """
         Deletes the specified table in Cloud Bigtable.
+
         Raises google.api_core.exceptions.NotFound if the table does not exist.
 
         :param instance_id: The ID of the Cloud Bigtable instance.
@@ -249,7 +250,7 @@ class BigtableHook(GoogleBaseHook):
         """
         instance = self.get_instance(instance_id=instance_id, project_id=project_id)
         if instance is None:
-            raise RuntimeError("Instance %s did not exist; unable to delete table %s" % instance_id, table_id)
+            raise RuntimeError(f"Instance {instance_id} did not exist; unable to delete table {table_id}")
         table = instance.table(table_id=table_id)
         table.delete()
 
@@ -257,6 +258,7 @@ class BigtableHook(GoogleBaseHook):
     def update_cluster(instance: Instance, cluster_id: str, nodes: int) -> None:
         """
         Updates number of nodes in the specified Cloud Bigtable cluster.
+
         Raises google.api_core.exceptions.NotFound if the cluster does not exist.
 
         :param instance: The Cloud Bigtable instance that owns the cluster.
@@ -285,6 +287,7 @@ class BigtableHook(GoogleBaseHook):
     def get_cluster_states_for_table(instance: Instance, table_id: str) -> dict[str, ClusterState]:
         """
         Fetches Cluster States for the specified table in Cloud Bigtable.
+
         Raises google.api_core.exceptions.NotFound if the table does not exist.
 
         :param instance: The Cloud Bigtable instance that owns the table.
