@@ -65,13 +65,13 @@ def _poll_with_exponential_delay(
                 log.info("Operation is done: %s", response)
                 return response
 
-            time.sleep((2**i) + (random.randint(0, 1000) / 1000))
+            time.sleep((2**i) + random.random())
         except HttpError as e:
             if e.resp.status != 429:
                 log.info("Something went wrong. Not retrying: %s", format(e))
                 raise
             else:
-                time.sleep((2**i) + (random.randint(0, 1000) / 1000))
+                time.sleep((2**i) + random.random())
 
     raise ValueError(f"Connection could not be established after {max_n} retries.")
 
@@ -84,6 +84,14 @@ class MLEngineHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
+
     def get_conn(self) -> Resource:
         """
         Retrieves the connection to MLEngine.
@@ -530,7 +538,7 @@ class MLEngineHook(GoogleBaseHook):
 
 
 class MLEngineAsyncHook(GoogleBaseAsyncHook):
-    """Class to get asynchronous hook for MLEngine"""
+    """Class to get asynchronous hook for MLEngine."""
 
     sync_hook_class = MLEngineHook
     scopes = ["https://www.googleapis.com/auth/cloud-platform"]
