@@ -18,7 +18,6 @@
 """This module contains a Google Cloud Natural Language Hook."""
 from __future__ import annotations
 
-import warnings
 from typing import Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -44,9 +43,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     Hook for Google Cloud Natural Language Service.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -60,16 +56,16 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
             )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self._conn: LanguageServiceClient | None = None
@@ -94,8 +90,9 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> AnalyzeEntitiesResponse:
         """
-        Finds named entities in the text along with entity types,
-        salience, mentions for each entity, and other properties.
+        Finds named entities in the text along with various properties.
+
+        Examples properties: entity types, salience, mentions for each entity, and others.
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
@@ -124,8 +121,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> AnalyzeEntitySentimentResponse:
         """
-        Finds entities, similar to AnalyzeEntities in the text and analyzes sentiment associated with each
-        entity and its mentions.
+        Similar to AnalyzeEntities, also analyzes sentiment associated with each entity and its mentions.
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
@@ -183,7 +179,9 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> AnalyzeSyntaxResponse:
         """
-        Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part
+        Analyzes the syntax of the text.
+
+        Provides sentence boundaries and tokenization along with part
         of speech tags, dependency trees, and other properties.
 
         :param document: Input document.
@@ -214,8 +212,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> AnnotateTextResponse:
         """
-        A convenience method that provides all the features that analyzeSentiment,
-        analyzeEntities, and analyzeSyntax provide in one call.
+        Provide all features that analyzeSentiment, analyzeEntities, and analyzeSyntax provide in one call.
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
