@@ -17,7 +17,7 @@
 # under the License.
 """This module contains a Google Cloud Vertex AI hook.
 
-.. spelling::
+.. spelling:word-list::
 
     undeployed
     undeploy
@@ -46,6 +46,14 @@ from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 class EndpointServiceHook(GoogleBaseHook):
     """Hook for Google Cloud Vertex AI Endpoint Service APIs."""
 
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
+
     def get_endpoint_service_client(self, region: str | None = None) -> EndpointServiceClient:
         """Returns EndpointServiceClient."""
         if region and region != "global":
@@ -308,8 +316,7 @@ class EndpointServiceHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Operation:
         """
-        Undeploys a Model from an Endpoint, removing a DeployedModel from it, and freeing all resources it's
-        using.
+        Undeploys a Model from an Endpoint, removing a DeployedModel from it, and freeing all used resources.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
