@@ -37,7 +37,7 @@ BIGQUERY_TABLE_LINK = (
 
 
 class BigQueryDatasetLink(BaseGoogleLink):
-    """Helper class for constructing BigQuery Dataset Link"""
+    """Helper class for constructing BigQuery Dataset Link."""
 
     name = "BigQuery Dataset"
     key = "bigquery_dataset"
@@ -58,7 +58,7 @@ class BigQueryDatasetLink(BaseGoogleLink):
 
 
 class BigQueryTableLink(BaseGoogleLink):
-    """Helper class for constructing BigQuery Table Link"""
+    """Helper class for constructing BigQuery Table Link."""
 
     name = "BigQuery Table"
     key = "bigquery_table"
