@@ -14,11 +14,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Handler that integrates with Stackdriver"""
+"""Handler that integrates with Stackdriver."""
 from __future__ import annotations
 
 import logging
 from contextvars import ContextVar
+from functools import cached_property
 from typing import Collection
 from urllib.parse import urlencode
 
@@ -29,7 +30,6 @@ from google.cloud.logging.handlers.transports import BackgroundThreadTransport,
 from google.cloud.logging_v2.services.logging_service_v2 import LoggingServiceV2Client
 from google.cloud.logging_v2.types import ListLogEntriesRequest, ListLogEntriesResponse
 
-from airflow.compat.functools import cached_property
 from airflow.models import TaskInstance
 from airflow.providers.google.cloud.utils.credentials_provider import get_credentials_and_project_id
 from airflow.providers.google.common.consts import CLIENT_INFO
@@ -119,7 +119,7 @@ class StackdriverTaskHandler(logging.Handler):
 
     @property
     def _client(self) -> gcp_logging.Client:
-        """The Cloud Library API client"""
+        """The Cloud Library API client."""
         credentials, project = self._credentials_and_project
         client = gcp_logging.Client(
             credentials=credentials,
@@ -140,13 +140,12 @@ class StackdriverTaskHandler(logging.Handler):
 
     @cached_property
     def _transport(self) -> Transport:
-        """Object responsible for sending data to Stackdriver"""
+        """Object responsible for sending data to Stackdriver."""
         # The Transport object is badly defined (no init) but in the docs client/name as constructor
         # arguments are a requirement for any class that derives from Transport class, hence ignore:
         return self.transport_type(self._client, self.name)  # type: ignore[call-arg]
 
     def _get_labels(self, task_instance=None):
-        """When"""
         if task_instance:
             ti_labels = self._task_instance_to_labels(task_instance)
         else:
@@ -179,7 +178,7 @@ class StackdriverTaskHandler(logging.Handler):
 
     def set_context(self, task_instance: TaskInstance) -> None:
         """
-        Configures the logger to add information with information about the current task
+        Configures the logger to add information with information about the current task.
 
         :param task_instance: Currently executed task
         """
@@ -315,10 +314,10 @@ class StackdriverTaskHandler(logging.Handler):
         )
         response = self._logging_service_client.list_log_entries(request=request)
         page: ListLogEntriesResponse = next(response.pages)
-        messages = []
+        messages: list[str] = []
         for entry in page.entries:
             if "message" in (entry.json_payload or {}):
-                messages.append(entry.json_payload["message"])
+                messages.append(entry.json_payload["message"])  # type: ignore
             elif entry.text_payload:
                 messages.append(entry.text_payload)
         return "\n".join(messages), page.next_page_token
@@ -350,8 +349,9 @@ class StackdriverTaskHandler(logging.Handler):
     def get_external_log_url(self, task_instance: TaskInstance, try_number: int) -> str:
         """
         Creates an address for an external log collecting service.
+
         :param task_instance: task instance object
-        :param try_number: task instance try_number to read logs from.
+        :param try_number: task instance try_number to read logs from
         :return: URL to the external log collection service
         """
         _, project_id = self._credentials_and_project
