@@ -15,7 +15,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Dict, List, Tuple
+from __future__ import annotations
+
+from typing import Any
 
 from trino.client import TrinoResult
 from trino.dbapi import Cursor as TrinoCursor
@@ -41,11 +43,11 @@ class _TrinoToGCSTrinoCursorAdapter:
 
     def __init__(self, cursor: TrinoCursor):
         self.cursor: TrinoCursor = cursor
-        self.rows: List[Any] = []
+        self.rows: list[Any] = []
         self.initialized: bool = False
 
     @property
-    def description(self) -> List[Tuple]:
+    def description(self) -> list[tuple]:
         """
         This read-only attribute is a sequence of 7-item sequences.
 
@@ -69,11 +71,11 @@ class _TrinoToGCSTrinoCursorAdapter:
 
     @property
     def rowcount(self) -> int:
-        """The read-only attribute specifies the number of rows"""
+        """The read-only attribute specifies the number of rows."""
         return self.cursor.rowcount
 
     def close(self) -> None:
-        """Close the cursor now"""
+        """Close the cursor now."""
         self.cursor.close()
 
     def execute(self, *args, **kwargs) -> TrinoResult:
@@ -84,8 +86,10 @@ class _TrinoToGCSTrinoCursorAdapter:
 
     def executemany(self, *args, **kwargs):
         """
-        Prepare a database operation (query or command) and then execute it against all parameter
-        sequences or mappings found in the sequence seq_of_parameters.
+        Prepare and execute a database query.
+
+        Prepare a database operation (query or command) and then execute it against
+        all parameter sequences or mappings found in the sequence seq_of_parameters.
         """
         self.initialized = False
         self.rows = []
@@ -99,18 +103,16 @@ class _TrinoToGCSTrinoCursorAdapter:
         return element
 
     def fetchone(self) -> Any:
-        """
-        Fetch the next row of a query result set, returning a single sequence, or
-        ``None`` when no more data is available.
-        """
+        """Fetch the next row of a query result set, returning a single sequence, or ``None``."""
         if self.rows:
             return self.rows.pop(0)
         return self.cursor.fetchone()
 
     def fetchmany(self, size=None) -> list:
         """
-        Fetch the next set of rows of a query result, returning a sequence of sequences
-        (e.g. a list of tuples). An empty sequence is returned when no more rows are available.
+        Fetch the next set of rows of a query result, returning a sequence of sequences.
+
+        An empty sequence is returned when no more rows are available.
         """
         if size is None:
             size = self.cursor.arraysize
@@ -126,17 +128,17 @@ class _TrinoToGCSTrinoCursorAdapter:
 
     def __next__(self) -> Any:
         """
-        Return the next row from the currently executing SQL statement using the same semantics as
-        ``.fetchone()``.  A ``StopIteration`` exception is raised when the result set is exhausted.
-        :return:
+        Return the next row from the current SQL statement using the same semantics as ``.fetchone()``.
+
+        A ``StopIteration`` exception is raised when the result set is exhausted.
         """
         result = self.fetchone()
         if result is None:
             raise StopIteration()
         return result
 
-    def __iter__(self) -> "_TrinoToGCSTrinoCursorAdapter":
-        """Return self to make cursors compatible to the iteration protocol"""
+    def __iter__(self) -> _TrinoToGCSTrinoCursorAdapter:
+        """Return self to make cursors compatible to the iteration protocol."""
         return self
 
 
@@ -186,7 +188,7 @@ class TrinoToGCSOperator(BaseSQLToGCSOperator):
         cursor.execute(self.sql)
         return _TrinoToGCSTrinoCursorAdapter(cursor)
 
-    def field_to_bigquery(self, field) -> Dict[str, str]:
+    def field_to_bigquery(self, field) -> dict[str, str]:
         """Convert trino field type to BigQuery field type."""
         clear_field_type = field[1].upper()
         # remove type argument e.g. DECIMAL(2, 10) => DECIMAL
