@@ -19,7 +19,7 @@ from __future__ import annotations
 import warnings
 from typing import TYPE_CHECKING, Any, Sequence
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.data_lake import AzureDataLakeHook
 
@@ -29,7 +29,7 @@ if TYPE_CHECKING:
 
 class LocalFilesystemToADLSOperator(BaseOperator):
     """
-    Upload file(s) to Azure Data Lake
+    Upload file(s) to Azure Data Lake.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -102,7 +102,9 @@ class LocalFilesystemToADLSOperator(BaseOperator):
 class LocalToAzureDataLakeStorageOperator(LocalFilesystemToADLSOperator):
     """
     This class is deprecated.
-    Please use `airflow.providers.microsoft.azure.transfers.local_to_adls.LocalFilesystemToADLSOperator`.
+
+    Please use
+    :class:`airflow.providers.microsoft.azure.transfers.local_to_adls.LocalFilesystemToADLSOperator`.
     """
 
     def __init__(self, *args, **kwargs):
@@ -110,7 +112,7 @@ class LocalToAzureDataLakeStorageOperator(LocalFilesystemToADLSOperator):
             """This class is deprecated.
             Please use
             `airflow.providers.microsoft.azure.transfers.local_to_adls.LocalFilesystemToADLSOperator`.""",
-            DeprecationWarning,
+            AirflowProviderDeprecationWarning,
             stacklevel=3,
         )
         super().__init__(*args, **kwargs)
