@@ -15,21 +15,25 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Hook for Mongo DB"""
+"""Hook for Mongo DB."""
 from __future__ import annotations
 
 from ssl import CERT_NONE
 from types import TracebackType
+from typing import Any, overload
+from urllib.parse import quote_plus, urlunsplit
 
 import pymongo
 from pymongo import MongoClient, ReplaceOne
 
 from airflow.hooks.base import BaseHook
+from airflow.typing_compat import Literal
 
 
 class MongoHook(BaseHook):
     """
     Interact with Mongo. This hook uses the Mongo conn_id.
+
     PyMongo Wrapper to Interact With Mongo Database
     Mongo Connection Documentation
     https://docs.mongodb.com/manual/reference/connection-string/index.html
@@ -51,19 +55,12 @@ class MongoHook(BaseHook):
     hook_name = "MongoDB"
 
     def __init__(self, conn_id: str = default_conn_name, *args, **kwargs) -> None:
-
         super().__init__()
         self.mongo_conn_id = conn_id
         self.connection = self.get_connection(conn_id)
         self.extras = self.connection.extra_dejson.copy()
-        self.client = None
-
-        srv = self.extras.pop("srv", False)
-        scheme = "mongodb+srv" if srv else "mongodb"
-
-        creds = f"{self.connection.login}:{self.connection.password}@" if self.connection.login else ""
-        port = "" if self.connection.port is None else f":{self.connection.port}"
-        self.uri = f"{scheme}://{creds}{self.connection.host}{port}/{self.connection.schema}"
+        self.client: MongoClient | None = None
+        self.uri = self._create_uri()
 
     def __enter__(self):
         return self
@@ -75,10 +72,11 @@ class MongoHook(BaseHook):
         exc_tb: TracebackType | None,
     ) -> None:
         if self.client is not None:
-            self.close_conn()
+            self.client.close()
+            self.client = None
 
     def get_conn(self) -> MongoClient:
-        """Fetches PyMongo Client"""
+        """Fetches PyMongo Client."""
         if self.client is not None:
             return self.client
 
@@ -87,18 +85,33 @@ class MongoHook(BaseHook):
 
         # If we are using SSL disable requiring certs from specific hostname
         if options.get("ssl", False):
-            options.update({"ssl_cert_reqs": CERT_NONE})
+            if pymongo.__version__ >= "4.0.0":
+                # In pymongo 4.0.0+ `tlsAllowInvalidCertificates=True`
+                # replaces `ssl_cert_reqs=CERT_NONE`
+                options.update({"tlsAllowInvalidCertificates": True})
+            else:
+                options.update({"ssl_cert_reqs": CERT_NONE})
 
         self.client = MongoClient(self.uri, **options)
-
         return self.client
 
-    def close_conn(self) -> None:
-        """Closes connection"""
-        client = self.client
-        if client is not None:
-            client.close()
-            self.client = None
+    def _create_uri(self) -> str:
+        """
+        Create URI string from the given credentials.
+
+        :return: URI string.
+        """
+        srv = self.extras.pop("srv", False)
+        scheme = "mongodb+srv" if srv else "mongodb"
+        login = self.connection.login
+        password = self.connection.password
+        netloc = self.connection.host
+        if login is not None and password is not None:
+            netloc = f"{quote_plus(login)}:{quote_plus(password)}@{netloc}"
+        if self.connection.port:
+            netloc = f"{netloc}:{self.connection.port}"
+        path = f"/{self.connection.schema}"
+        return urlunsplit((scheme, netloc, path, "", ""))
 
     def get_collection(
         self, mongo_collection: str, mongo_db: str | None = None
@@ -108,7 +121,7 @@ class MongoHook(BaseHook):
 
         Uses connection schema as DB unless specified.
         """
-        mongo_db = mongo_db if mongo_db is not None else self.connection.schema
+        mongo_db = mongo_db or self.connection.schema
         mongo_conn: MongoClient = self.get_conn()
 
         return mongo_conn.get_database(mongo_db).get_collection(mongo_collection)
@@ -117,7 +130,8 @@ class MongoHook(BaseHook):
         self, mongo_collection: str, aggregate_query: list, mongo_db: str | None = None, **kwargs
     ) -> pymongo.command_cursor.CommandCursor:
         """
-        Runs an aggregation pipeline and returns the results
+        Runs an aggregation pipeline and returns the results.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.aggregate
         https://pymongo.readthedocs.io/en/stable/examples/aggregation.html
         """
@@ -125,6 +139,30 @@ class MongoHook(BaseHook):
 
         return collection.aggregate(aggregate_query, **kwargs)
 
+    @overload
+    def find(
+        self,
+        mongo_collection: str,
+        query: dict,
+        find_one: Literal[False],
+        mongo_db: str | None = None,
+        projection: list | dict | None = None,
+        **kwargs,
+    ) -> pymongo.cursor.Cursor:
+        ...
+
+    @overload
+    def find(
+        self,
+        mongo_collection: str,
+        query: dict,
+        find_one: Literal[True],
+        mongo_db: str | None = None,
+        projection: list | dict | None = None,
+        **kwargs,
+    ) -> Any | None:
+        ...
+
     def find(
         self,
         mongo_collection: str,
@@ -133,9 +171,10 @@ class MongoHook(BaseHook):
         mongo_db: str | None = None,
         projection: list | dict | None = None,
         **kwargs,
-    ) -> pymongo.cursor.Cursor:
+    ) -> pymongo.cursor.Cursor | Any | None:
         """
-        Runs a mongo find query and returns the results
+        Runs a mongo find query and returns the results.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.find
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
@@ -149,7 +188,8 @@ class MongoHook(BaseHook):
         self, mongo_collection: str, doc: dict, mongo_db: str | None = None, **kwargs
     ) -> pymongo.results.InsertOneResult:
         """
-        Inserts a single document into a mongo collection
+        Inserts a single document into a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.insert_one
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
@@ -161,6 +201,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.InsertManyResult:
         """
         Inserts many docs into a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.insert_many
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
@@ -177,6 +218,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.UpdateResult:
         """
         Updates a single document in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.update_one
 
         :param mongo_collection: The name of the collection to update.
@@ -200,6 +242,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.UpdateResult:
         """
         Updates one or more documents in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.update_many
 
         :param mongo_collection: The name of the collection to update.
@@ -207,7 +250,6 @@ class MongoHook(BaseHook):
         :param update_doc: The modifications to apply.
         :param mongo_db: The name of the database to use.
             Can be omitted; then the database from the connection string is used.
-
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
 
@@ -223,6 +265,7 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.UpdateResult:
         """
         Replaces a single document in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.replace_one
 
         .. note::
@@ -275,7 +318,6 @@ class MongoHook(BaseHook):
         :param collation: An instance of
             :class:`~pymongo.collation.Collation`. This option is only
             supported on MongoDB 3.4 and above.
-
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
 
@@ -293,13 +335,13 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.DeleteResult:
         """
         Deletes a single document in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.delete_one
 
         :param mongo_collection: The name of the collection to delete from.
         :param filter_doc: A query that matches the document to delete.
         :param mongo_db: The name of the database to use.
             Can be omitted; then the database from the connection string is used.
-
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
 
@@ -310,13 +352,13 @@ class MongoHook(BaseHook):
     ) -> pymongo.results.DeleteResult:
         """
         Deletes one or more documents in a mongo collection.
+
         https://pymongo.readthedocs.io/en/stable/api/pymongo/collection.html#pymongo.collection.Collection.delete_many
 
         :param mongo_collection: The name of the collection to delete from.
         :param filter_doc: A query that matches the documents to delete.
         :param mongo_db: The name of the database to use.
             Can be omitted; then the database from the connection string is used.
-
         """
         collection = self.get_collection(mongo_collection, mongo_db=mongo_db)
 
