@@ -15,11 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """This module contains AWS S3 to Snowflake operator."""
-import warnings
-from typing import Any, Optional, Sequence
+from __future__ import annotations
 
+import warnings
+from typing import Any, Sequence
+
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.snowflake.hooks.snowflake import SnowflakeHook
 from airflow.providers.snowflake.utils.common import enclose_param
@@ -27,7 +29,7 @@ from airflow.providers.snowflake.utils.common import enclose_param
 
 class S3ToSnowflakeOperator(BaseOperator):
     """
-    Executes an COPY command to load files from s3 to Snowflake
+    Executes an COPY command to load files from s3 to Snowflake.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -69,21 +71,21 @@ class S3ToSnowflakeOperator(BaseOperator):
     def __init__(
         self,
         *,
-        s3_keys: Optional[list] = None,
+        s3_keys: list | None = None,
         table: str,
         stage: str,
-        prefix: Optional[str] = None,
+        prefix: str | None = None,
         file_format: str,
-        schema: Optional[str] = None,
-        columns_array: Optional[list] = None,
-        pattern: Optional[str] = None,
-        warehouse: Optional[str] = None,
-        database: Optional[str] = None,
+        schema: str | None = None,
+        columns_array: list | None = None,
+        pattern: str | None = None,
+        warehouse: str | None = None,
+        database: str | None = None,
         autocommit: bool = True,
-        snowflake_conn_id: str = 'snowflake_default',
-        role: Optional[str] = None,
-        authenticator: Optional[str] = None,
-        session_parameters: Optional[dict] = None,
+        snowflake_conn_id: str = "snowflake_default",
+        role: str | None = None,
+        authenticator: str | None = None,
+        session_parameters: dict | None = None,
         **kwargs,
     ) -> None:
         warnings.warn(
@@ -92,7 +94,7 @@ class S3ToSnowflakeOperator(BaseOperator):
             Please use
             `airflow.providers.snowflake.transfers.copy_into_snowflake.CopyFromExternalStageToSnowflakeOperator`.
             """,
-            DeprecationWarning,
+            AirflowProviderDeprecationWarning,
             stacklevel=2,
         )
         super().__init__(**kwargs)
@@ -142,6 +144,6 @@ class S3ToSnowflakeOperator(BaseOperator):
             sql_parts.append(f"pattern={enclose_param(self.pattern)}")
         copy_query = "\n".join(sql_parts)
 
-        self.log.info('Executing COPY command...')
+        self.log.info("Executing COPY command...")
         snowflake_hook.run(copy_query, self.autocommit)
         self.log.info("COPY command completed")
