@@ -1,4 +1,3 @@
-#
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -18,25 +17,26 @@
 from __future__ import annotations
 
 import warnings
-from typing import Any, Collection, Container, Iterable, Sequence
+from typing import TYPE_CHECKING, Any, Collection, Container, Iterable, Sequence
 
 from flask import g
 from sqlalchemy import or_
-from sqlalchemy.orm import Session, joinedload
+from sqlalchemy.orm import joinedload
 
+from airflow.auth.managers.fab.models import Permission, Resource, Role, User
+from airflow.auth.managers.fab.views.user_details import CustomUserDBModelView
 from airflow.exceptions import AirflowException, RemovedInAirflow3Warning
 from airflow.models import DagBag, DagModel
 from airflow.security import permissions
 from airflow.utils.log.logging_mixin import LoggingMixin
 from airflow.utils.session import NEW_SESSION, provide_session
+from airflow.www.extensions.init_auth_manager import get_auth_manager
 from airflow.www.fab_security.sqla.manager import SecurityManager
-from airflow.www.fab_security.sqla.models import Permission, Resource, Role, User
 from airflow.www.fab_security.views import (
     ActionModelView,
     CustomResetMyPasswordView,
     CustomResetPasswordView,
     CustomRoleModelView,
-    CustomUserDBModelView,
     CustomUserInfoEditView,
     CustomUserLDAPModelView,
     CustomUserOAuthModelView,
@@ -56,9 +56,25 @@ EXISTING_ROLES = {
     "Public",
 }
 
+if TYPE_CHECKING:
+    from sqlalchemy.orm import Session
 
-class AirflowSecurityManager(SecurityManager, LoggingMixin):
-    """Custom security manager, which introduces a permission model adapted to Airflow"""
+    SecurityManagerOverride: type = object
+else:
+    # Fetch the security manager override from the auth manager
+    SecurityManagerOverride = get_auth_manager().get_security_manager_override_class()
+
+EXISTING_ROLES = {
+    "Admin",
+    "Viewer",
+    "User",
+    "Op",
+    "Public",
+}
+
+
+class AirflowSecurityManager(SecurityManagerOverride, SecurityManager, LoggingMixin):
+    """Custom security manager, which introduces a permission model adapted to Airflow."""
 
     ###########################################################################
     #                               PERMISSIONS
@@ -72,6 +88,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         (permissions.ACTION_CAN_READ, permissions.RESOURCE_DAG_CODE),
         (permissions.ACTION_CAN_READ, permissions.RESOURCE_DAG_RUN),
         (permissions.ACTION_CAN_READ, permissions.RESOURCE_DATASET),
+        (permissions.ACTION_CAN_READ, permissions.RESOURCE_CLUSTER_ACTIVITY),
         (permissions.ACTION_CAN_READ, permissions.RESOURCE_IMPORT_ERROR),
         (permissions.ACTION_CAN_READ, permissions.RESOURCE_DAG_WARNING),
         (permissions.ACTION_CAN_READ, permissions.RESOURCE_JOB),
@@ -90,6 +107,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         (permissions.ACTION_CAN_ACCESS_MENU, permissions.RESOURCE_DAG_DEPENDENCIES),
         (permissions.ACTION_CAN_ACCESS_MENU, permissions.RESOURCE_DAG_RUN),
         (permissions.ACTION_CAN_ACCESS_MENU, permissions.RESOURCE_DATASET),
+        (permissions.ACTION_CAN_ACCESS_MENU, permissions.RESOURCE_CLUSTER_ACTIVITY),
         (permissions.ACTION_CAN_ACCESS_MENU, permissions.RESOURCE_DOCS),
         (permissions.ACTION_CAN_ACCESS_MENU, permissions.RESOURCE_DOCS_MENU),
         (permissions.ACTION_CAN_ACCESS_MENU, permissions.RESOURCE_JOB),
@@ -190,7 +208,32 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
     userstatschartview = CustomUserStatsChartView
 
     def __init__(self, appbuilder) -> None:
-        super().__init__(appbuilder)
+        super().__init__(
+            appbuilder=appbuilder,
+            actionmodelview=self.actionmodelview,
+            authdbview=self.authdbview,
+            authldapview=self.authldapview,
+            authoauthview=self.authoauthview,
+            authoidview=self.authoidview,
+            authremoteuserview=self.authremoteuserview,
+            permissionmodelview=self.permissionmodelview,
+            registeruser_view=self.registeruser_view,
+            registeruserdbview=self.registeruserdbview,
+            registeruseroauthview=self.registeruseroauthview,
+            registerusermodelview=self.registerusermodelview,
+            registeruseroidview=self.registeruseroidview,
+            resetmypasswordview=self.resetmypasswordview,
+            resetpasswordview=self.resetpasswordview,
+            rolemodelview=self.rolemodelview,
+            user_model=self.user_model,
+            userinfoeditview=self.userinfoeditview,
+            userdbmodelview=self.userdbmodelview,
+            userldapmodelview=self.userldapmodelview,
+            useroauthmodelview=self.useroauthmodelview,
+            useroidmodelview=self.useroidmodelview,
+            userremoteusermodelview=self.userremoteusermodelview,
+            userstatschartview=self.userstatschartview,
+        )
 
         # Go and fix up the SQLAInterface used from the stock one to our subclass.
         # This is needed to support the "hack" where we had to edit
@@ -223,6 +266,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
     def init_role(self, role_name, perms) -> None:
         """
         Initialize the role with actions and related resources.
+
         :param role_name:
         :param perms:
         :return:
@@ -254,7 +298,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
 
     def delete_role(self, role_name: str) -> None:
         """
-        Delete the given Role
+        Delete the given Role.
 
         :param role_name: the name of a role in the ab_role table
         """
@@ -335,7 +379,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         if not user_actions:
             user_actions = [permissions.ACTION_CAN_EDIT, permissions.ACTION_CAN_READ]
 
-        if user.is_anonymous:
+        if not get_auth_manager().is_logged_in():
             roles = user.roles
         else:
             if (permissions.ACTION_CAN_EDIT in user_actions and self.can_edit_all_dags(user)) or (
@@ -419,8 +463,9 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
 
     def has_access(self, action_name: str, resource_name: str, user=None) -> bool:
         """
-        Verify whether a given user could perform a certain action
-        (e.g can_read, can_write, can_delete) on the given resource.
+        Verify whether a given user could perform a certain action on the given resource.
+
+        Example actions might include can_read, can_write, can_delete, etc.
 
         :param action_name: action_name on resource (e.g can_read, can_edit).
         :param resource_name: name of view-menu or resource.
@@ -441,14 +486,15 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         return False
 
     def _has_role(self, role_name_or_list: Container, user) -> bool:
-        """Whether the user has this role name"""
+        """Whether the user has this role name."""
         if not isinstance(role_name_or_list, list):
             role_name_or_list = [role_name_or_list]
         return any(r.name in role_name_or_list for r in user.roles)
 
     def has_all_dags_access(self, user) -> bool:
         """
-        Has all the dag access in any of the 3 cases:
+        Has all the dag access in any of the 3 cases.
+
         1. Role needs to be in (Admin, Viewer, User, Op).
         2. Has can_read action on dags resource.
         3. Has can_edit action on dags resource.
@@ -462,15 +508,15 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         )
 
     def can_edit_all_dags(self, user=None) -> bool:
-        """Has can_edit action on DAG resource"""
+        """Has can_edit action on DAG resource."""
         return self.has_access(permissions.ACTION_CAN_EDIT, permissions.RESOURCE_DAG, user)
 
     def can_read_all_dags(self, user=None) -> bool:
-        """Has can_read action on DAG resource"""
+        """Has can_read action on DAG resource."""
         return self.has_access(permissions.ACTION_CAN_READ, permissions.RESOURCE_DAG, user)
 
     def clean_perms(self) -> None:
-        """FAB leaves faulty permissions that need to be cleaned up"""
+        """FAB leaves faulty permissions that need to be cleaned up."""
         self.log.debug("Cleaning faulty perms")
         sesh = self.appbuilder.get_session
         perms = sesh.query(Permission).filter(
@@ -494,6 +540,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
     def _merge_perm(self, action_name: str, resource_name: str) -> None:
         """
         Add the new (action, resource) to assoc_permission_role if it doesn't exist.
+
         It will add the related entry to ab_permission and ab_resource two meta tables as well.
 
         :param action_name: Name of the action
@@ -526,7 +573,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         self.appbuilder.get_session.commit()
 
     def get_all_permissions(self) -> set[tuple[str, str]]:
-        """Returns all permissions as a set of tuples with the action and resource names"""
+        """Returns all permissions as a set of tuples with the action and resource names."""
         return set(
             self.appbuilder.get_session.query(self.permission_model)
             .join(self.permission_model.action)
@@ -537,6 +584,8 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
 
     def _get_all_non_dag_permissions(self) -> dict[tuple[str, str], Permission]:
         """
+        Get permissions except those that are for specific DAGs.
+
         Returns a dict with a key of (action_name, resource_name) and value of permission
         with all permissions except those that are for specific DAGs.
         """
@@ -553,7 +602,7 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         }
 
     def _get_all_roles_with_permissions(self) -> dict[str, Role]:
-        """Returns a dict with a key of role name and value of role with early loaded permissions"""
+        """Returns a dict with a key of role name and value of role with early loaded permissions."""
         return {
             r.name: r
             for r in self.appbuilder.get_session.query(self.role_model).options(
@@ -563,6 +612,8 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
 
     def create_dag_specific_permissions(self) -> None:
         """
+        Add permissions to all DAGs.
+
         Creates 'can_read', 'can_edit', and 'can_delete' permissions for all
         DAGs, along with any `access_control` permissions provided in them.
 
@@ -583,12 +634,14 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
                 if (action_name, dag_resource_name) not in perms:
                     self._merge_perm(action_name, dag_resource_name)
 
-            if dag.access_control:
+            if dag.access_control is not None:
                 self.sync_perm_for_dag(dag_resource_name, dag.access_control)
 
     def update_admin_permission(self) -> None:
         """
-        Admin should have all the permissions, except the dag permissions.
+        Add missing permissions to the table for admin.
+
+        Admin should get all the permissions, except the dag permissions
         because Admin already has Dags permission.
         Add the missing ones to the table for admin.
 
@@ -610,6 +663,8 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
 
     def sync_roles(self) -> None:
         """
+        Initialize default and custom roles with related permissions.
+
         1. Init the default role(Admin, Viewer, User, Op, public)
            with related permissions.
         2. Init the custom role(dag-user) with related permissions.
@@ -642,8 +697,9 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         access_control: dict[str, Collection[str]] | None = None,
     ) -> None:
         """
-        Sync permissions for given dag id. The dag id surely exists in our dag bag
-        as only / refresh button or DagBag will call this function
+        Sync permissions for given dag id.
+
+        The dag id surely exists in our dag bag as only / refresh button or DagBag will call this function.
 
         :param dag_id: the ID of the DAG whose permissions should be updated
         :param access_control: a dict where each key is a rolename and
@@ -655,8 +711,14 @@ class AirflowSecurityManager(SecurityManager, LoggingMixin):
         for dag_action_name in self.DAG_ACTIONS:
             self.create_permission(dag_action_name, dag_resource_name)
 
-        if access_control:
+        if access_control is not None:
+            self.log.debug("Syncing DAG-level permissions for DAG '%s'", dag_resource_name)
             self._sync_dag_view_permissions(dag_resource_name, access_control)
+        else:
+            self.log.debug(
+                "Not syncing DAG-level permissions for DAG '%s' as access control is unset.",
+                dag_resource_name,
+            )
 
     def _sync_dag_view_permissions(self, dag_id: str, access_control: dict[str, Collection[str]]) -> None:
         """
@@ -767,7 +829,7 @@ class FakeAppBuilder:
 
 
 class ApplessAirflowSecurityManager(AirflowSecurityManager):
-    """Security Manager that doesn't need the whole flask app"""
+    """Security Manager that doesn't need the whole flask app."""
 
     def __init__(self, session: Session | None = None):
         self.appbuilder = FakeAppBuilder(session)
